@@ -1,14 +1,11 @@
 """Collection of functions for the manipulation of time series."""
 
-
 import itertools
 import os
 import warnings
 
-import cltoolbox
 import matplotlib
 import matplotlib.pyplot as plt
-from cltoolbox.rst_text_formatter import RSTHelpFormatter
 from toolbox_utils import tsutils
 
 from .. import plotutils
@@ -21,156 +18,6 @@ warnings.filterwarnings("ignore")
 plotutils.HATCH_LIST = ["/", "\\", "|", "-", "+", "x", "o", "O", ".", "*"]
 
 
-@cltoolbox.command("barh", formatter_class=RSTHelpFormatter)
-@tsutils.doc(plotutils.ldocstrings)
-def barh_cli(
-    input_ts="-",
-    columns=None,
-    start_date=None,
-    end_date=None,
-    clean=False,
-    skiprows=None,
-    index_type="datetime",
-    names=None,
-    ofilename="plot.png",
-    xtitle="",
-    ytitle="",
-    title="",
-    figsize="10,6.0",
-    legend=None,
-    legend_names=None,
-    colors="auto",
-    linestyles="auto",
-    markerstyles=" ",
-    bar_hatchstyles="auto",
-    style="auto",
-    xaxis="arithmetic",
-    yaxis="arithmetic",
-    xlim=None,
-    ylim=None,
-    grid=False,
-    label_rotation=None,
-    label_skip=1,
-    force_freq=None,
-    por=False,
-    invert_xaxis=False,
-    invert_yaxis=False,
-    round_index=None,
-    source_units=None,
-    target_units=None,
-    plot_styles="bright",
-    hlines_y=None,
-    hlines_xmin=None,
-    hlines_xmax=None,
-    hlines_colors=None,
-    hlines_linestyles="-",
-    vlines_x=None,
-    vlines_ymin=None,
-    vlines_ymax=None,
-    vlines_colors=None,
-    vlines_linestyles="-",
-):
-    r"""Bar plot, sometimes called a "column" plot.
-
-    "barh" creates a horizontal bar plot.
-
-    Parameters
-    ----------
-    ${input_ts}
-    ${columns}
-    ${start_date}
-    ${end_date}
-    ${clean}
-    ${skiprows}
-    ${index_type}
-    ${names}
-    ${ofilename}
-    ${xtitle}
-    ${ytitle}
-    ${title}
-    ${figsize}
-    ${legend}
-    ${legend_names}
-    ${colors}
-    ${linestyles}
-    ${markerstyles}
-    ${bar_hatchstyles}
-    ${style}
-    ${xaxis}
-    ${yaxis}
-    ${xlim}
-    ${ylim}
-    ${grid}
-    ${label_rotation}
-    ${label_skip}
-    ${force_freq}
-    ${por}
-    ${invert_xaxis}
-    ${invert_yaxis}
-    ${round_index}
-    ${source_units}
-    ${target_units}
-    ${plot_styles}
-    ${hlines_y}
-    ${hlines_xmin}
-    ${hlines_xmax}
-    ${hlines_colors}
-    ${hlines_linestyles}
-    ${vlines_x}
-    ${vlines_ymin}
-    ${vlines_ymax}
-    ${vlines_colors}
-    ${vlines_linestyles}
-    """
-    barh(
-        input_ts=input_ts,
-        columns=columns,
-        start_date=start_date,
-        end_date=end_date,
-        clean=clean,
-        skiprows=skiprows,
-        index_type=index_type,
-        names=names,
-        ofilename=ofilename,
-        xtitle=xtitle,
-        ytitle=ytitle,
-        title=title,
-        figsize=figsize,
-        legend=legend,
-        legend_names=legend_names,
-        colors=colors,
-        linestyles=linestyles,
-        markerstyles=markerstyles,
-        bar_hatchstyles=bar_hatchstyles,
-        style=style,
-        xaxis=xaxis,
-        yaxis=yaxis,
-        xlim=xlim,
-        ylim=ylim,
-        grid=grid,
-        label_rotation=label_rotation,
-        label_skip=label_skip,
-        force_freq=force_freq,
-        por=por,
-        invert_xaxis=invert_xaxis,
-        invert_yaxis=invert_yaxis,
-        round_index=round_index,
-        source_units=source_units,
-        target_units=target_units,
-        plot_styles=plot_styles,
-        hlines_y=hlines_y,
-        hlines_xmin=hlines_xmin,
-        hlines_xmax=hlines_xmax,
-        hlines_colors=hlines_colors,
-        hlines_linestyles=hlines_linestyles,
-        vlines_x=vlines_x,
-        vlines_ymin=vlines_ymin,
-        vlines_ymax=vlines_ymax,
-        vlines_colors=vlines_colors,
-        vlines_linestyles=vlines_linestyles,
-    )
-
-
 def barh(
     input_ts="-",
     columns=None,
@@ -395,6 +242,3 @@ def barh(
     if ofilename is not None:
         plt.savefig(ofilename)
     return plt
-
-
-barh.__doc__ = barh_cli.__doc__
