@@ -1,14 +1,11 @@
 """Collection of functions for the manipulation of time series."""
 
-
 import os
 import warnings
 
-import cltoolbox
 import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
-from cltoolbox.rst_text_formatter import RSTHelpFormatter
 from toolbox_utils import tsutils
 
 from .. import plotutils
@@ -18,149 +15,6 @@ matplotlib.use("Agg")
 warnings.filterwarnings("ignore")
 
 
-@cltoolbox.command("double_mass", formatter_class=RSTHelpFormatter)
-@tsutils.doc(plotutils.ldocstrings)
-def double_mass_cli(
-    input_ts="-",
-    columns=None,
-    start_date=None,
-    end_date=None,
-    clean=False,
-    skiprows=None,
-    index_type="datetime",
-    names=None,
-    ofilename="plot.png",
-    xtitle="",
-    ytitle="",
-    title="",
-    figsize="10,6.0",
-    legend=None,
-    legend_names=None,
-    colors="auto",
-    linestyles="auto",
-    markerstyles=" ",
-    style="auto",
-    xaxis="arithmetic",
-    yaxis="arithmetic",
-    xlim=None,
-    ylim=None,
-    grid=False,
-    drawstyle="default",
-    por=False,
-    invert_xaxis=False,
-    invert_yaxis=False,
-    round_index=None,
-    source_units=None,
-    target_units=None,
-    plot_styles="bright",
-    hlines_y=None,
-    hlines_xmin=None,
-    hlines_xmax=None,
-    hlines_colors=None,
-    hlines_linestyles="-",
-    vlines_x=None,
-    vlines_ymin=None,
-    vlines_ymax=None,
-    vlines_colors=None,
-    vlines_linestyles="-",
-):
-    r"""Double mass curve - cumulative sum of x against cumulative sum of y.
-
-    "double_mass" creates a 'x,y' plot of the cumulative sum of x and y.
-
-    ${xydata}
-
-    Parameters
-    ----------
-    ${input_ts}
-    ${columns}
-    ${start_date}
-    ${end_date}
-    ${clean}
-    ${skiprows}
-    ${index_type}
-    ${names}
-    ${ofilename}
-    ${xtitle}
-    ${ytitle}
-    ${title}
-    ${figsize}
-    ${legend}
-    ${legend_names}
-    ${colors}
-    ${linestyles}
-    ${markerstyles}
-    ${style}
-    ${xaxis}
-    ${yaxis}
-    ${xlim}
-    ${ylim}
-    ${grid}
-    ${drawstyle}
-    ${por}
-    ${invert_xaxis}
-    ${invert_yaxis}
-    ${round_index}
-    ${source_units}
-    ${target_units}
-    ${plot_styles}
-    ${hlines_y}
-    ${hlines_xmin}
-    ${hlines_xmax}
-    ${hlines_colors}
-    ${hlines_linestyles}
-    ${vlines_x}
-    ${vlines_ymin}
-    ${vlines_ymax}
-    ${vlines_colors}
-    ${vlines_linestyles}
-    """
-    double_mass(
-        input_ts=input_ts,
-        columns=columns,
-        start_date=start_date,
-        end_date=end_date,
-        clean=clean,
-        skiprows=skiprows,
-        index_type=index_type,
-        names=names,
-        ofilename=ofilename,
-        xtitle=xtitle,
-        ytitle=ytitle,
-        title=title,
-        figsize=figsize,
-        legend=legend,
-        legend_names=legend_names,
-        colors=colors,
-        linestyles=linestyles,
-        markerstyles=markerstyles,
-        style=style,
-        xaxis=xaxis,
-        yaxis=yaxis,
-        xlim=xlim,
-        ylim=ylim,
-        grid=grid,
-        drawstyle=drawstyle,
-        por=por,
-        invert_xaxis=invert_xaxis,
-        invert_yaxis=invert_yaxis,
-        round_index=round_index,
-        source_units=source_units,
-        target_units=target_units,
-        plot_styles=plot_styles,
-        hlines_y=hlines_y,
-        hlines_xmin=hlines_xmin,
-        hlines_xmax=hlines_xmax,
-        hlines_colors=hlines_colors,
-        hlines_linestyles=hlines_linestyles,
-        vlines_x=vlines_x,
-        vlines_ymin=vlines_ymin,
-        vlines_ymax=vlines_ymax,
-        vlines_colors=vlines_colors,
-        vlines_linestyles=vlines_linestyles,
-    )
-
-
 def double_mass(
     input_ts="-",
     columns=None,
@@ -230,11 +84,10 @@ def double_mass(
             raise AttributeError(
                 tsutils.error_wrapper(
                     """
-The 'double_mass' type must have an even number of columns arranged
-as x,y pairs or an x-index and one y data column.  You supplied {} columns.
-""".format(
-                        tsd.shape[1]
-                    )
+                    The 'double_mass' type must have an even number of columns
+                    arranged as x,y pairs or an x-index and one y data column.
+                    You supplied {len(tsd.columns)} columns.
+                    """
                 )
             )
     colcnt = tsd.shape[1] // 2
@@ -370,6 +223,3 @@ as x,y pairs or an x-index and one y data column.  You supplied {} columns.
     if ofilename is not None:
         plt.savefig(ofilename)
     return plt
-
-
-double_mass.__doc__ = double_mass_cli.__doc__
