@@ -1,15 +1,12 @@
 """Collection of functions for the manipulation of time series."""
 
-
 import os
 import warnings
 
-import cltoolbox
 import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-from cltoolbox.rst_text_formatter import RSTHelpFormatter
 from toolbox_utils import tsutils
 
 from .. import plotutils
@@ -19,133 +16,6 @@ matplotlib.use("Agg")
 warnings.filterwarnings("ignore")
 
 
-@cltoolbox.command("heatmap", formatter_class=RSTHelpFormatter)
-@tsutils.doc(plotutils.ldocstrings)
-def heatmap_cli(
-    input_ts="-",
-    columns=None,
-    start_date=None,
-    end_date=None,
-    clean=False,
-    skiprows=None,
-    index_type="datetime",
-    names=None,
-    ofilename="plot.png",
-    xtitle="",
-    ytitle="",
-    title="",
-    figsize="10,6.0",
-    legend=None,
-    legend_names=None,
-    colors="auto",
-    linestyles="auto",
-    markerstyles=" ",
-    style="auto",
-    grid=False,
-    por=False,
-    invert_xaxis=False,
-    invert_yaxis=False,
-    round_index=None,
-    source_units=None,
-    target_units=None,
-    plot_styles="bright",
-    hlines_y=None,
-    hlines_xmin=None,
-    hlines_xmax=None,
-    hlines_colors=None,
-    hlines_linestyles="-",
-    vlines_x=None,
-    vlines_ymin=None,
-    vlines_ymax=None,
-    vlines_colors=None,
-    vlines_linestyles="-",
-):
-    r"""2D heatmap of daily data.
-
-    "heatmap" creates a 2D heatmap of daily data, day of year x-axis, and year
-    for y-axis.  Only available for a single, daily time-series.
-
-    Parameters
-    ----------
-    ${input_ts}
-    ${columns}
-    ${start_date}
-    ${end_date}
-    ${clean}
-    ${skiprows}
-    ${index_type}
-    ${names}
-    ${ofilename}
-    ${xtitle}
-    ${ytitle}
-    ${title}
-    ${figsize}
-    ${legend}
-    ${legend_names}
-    ${colors}
-    ${linestyles}
-    ${markerstyles}
-    ${style}
-    ${grid}
-    ${por}
-    ${invert_xaxis}
-    ${invert_yaxis}
-    ${round_index}
-    ${source_units}
-    ${target_units}
-    ${plot_styles}
-    ${hlines_y}
-    ${hlines_xmin}
-    ${hlines_xmax}
-    ${hlines_colors}
-    ${hlines_linestyles}
-    ${vlines_x}
-    ${vlines_ymin}
-    ${vlines_ymax}
-    ${vlines_colors}
-    ${vlines_linestyles}
-    """
-    heatmap(
-        input_ts=input_ts,
-        columns=columns,
-        start_date=start_date,
-        end_date=end_date,
-        clean=clean,
-        skiprows=skiprows,
-        index_type=index_type,
-        names=names,
-        ofilename=ofilename,
-        xtitle=xtitle,
-        ytitle=ytitle,
-        title=title,
-        figsize=figsize,
-        legend=legend,
-        legend_names=legend_names,
-        colors=colors,
-        linestyles=linestyles,
-        markerstyles=markerstyles,
-        style=style,
-        grid=grid,
-        por=por,
-        invert_xaxis=invert_xaxis,
-        invert_yaxis=invert_yaxis,
-        round_index=round_index,
-        source_units=source_units,
-        target_units=target_units,
-        plot_styles=plot_styles,
-        hlines_y=hlines_y,
-        hlines_xmin=hlines_xmin,
-        hlines_xmax=hlines_xmax,
-        hlines_colors=hlines_colors,
-        hlines_linestyles=hlines_linestyles,
-        vlines_x=vlines_x,
-        vlines_ymin=vlines_ymin,
-        vlines_ymax=vlines_ymax,
-        vlines_colors=vlines_colors,
-        vlines_linestyles=vlines_linestyles,
-    )
-
-
 @tsutils.transform_args(figsize=tsutils.make_list)
 def heatmap(
     input_ts="-",
@@ -249,8 +119,8 @@ def heatmap(
         raise ValueError(
             tsutils.error_wrapper(
                 """
-The "heatmap" plot type can only work with daily time series.
-"""
+                The "heatmap" plot type can only work with daily time series.
+                """
             )
         )
     dr = pd.date_range(f"{byear}-01-01", f"{eyear}-12-31", freq="D")
@@ -324,6 +194,3 @@ The "heatmap" plot type can only work with daily time series.
     if ofilename is not None:
         plt.savefig(ofilename)
     return plt
-
-
-heatmap.__doc__ = heatmap_cli.__doc__
