@@ -1,15 +1,12 @@
 """Collection of functions for the manipulation of time series."""
 
-
 import itertools
 import os
 import warnings
 
-import cltoolbox
 import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
-from cltoolbox.rst_text_formatter import RSTHelpFormatter
 from scipy.stats import gaussian_kde
 from toolbox_utils import tsutils
 
@@ -20,165 +17,6 @@ matplotlib.use("Agg")
 warnings.filterwarnings("ignore")
 
 
-@cltoolbox.command("kde_time", formatter_class=RSTHelpFormatter)
-@tsutils.doc(plotutils.ldocstrings)
-def kde_time_cli(
-    input_ts="-",
-    columns=None,
-    start_date=None,
-    end_date=None,
-    clean=False,
-    skiprows=None,
-    index_type="datetime",
-    names=None,
-    ofilename="plot.png",
-    xtitle="",
-    ytitle="",
-    title="",
-    figsize="10,6.0",
-    legend=None,
-    legend_names=None,
-    subplots=False,
-    sharex=True,
-    sharey=False,
-    colors="auto",
-    linestyles="auto",
-    markerstyles=" ",
-    style="auto",
-    xaxis="arithmetic",
-    yaxis="arithmetic",
-    xlim=None,
-    ylim=None,
-    secondary_y=False,
-    mark_right=True,
-    grid=False,
-    drawstyle="default",
-    por=False,
-    invert_xaxis=False,
-    invert_yaxis=False,
-    round_index=None,
-    source_units=None,
-    target_units=None,
-    plot_styles="bright",
-    hlines_y=None,
-    hlines_xmin=None,
-    hlines_xmax=None,
-    hlines_colors=None,
-    hlines_linestyles="-",
-    vlines_x=None,
-    vlines_ymin=None,
-    vlines_ymax=None,
-    vlines_colors=None,
-    vlines_linestyles="-",
-):
-    r"""A time-series plot with a kernel density estimation (KDE) plot.
-
-    This plot is an estimation of the probability density function based on the
-    data called kernel density estimation (KDE) combined with a time-series
-    plot.
-
-    Parameters
-    ----------
-    ${input_ts}
-    ${columns}
-    ${start_date}
-    ${end_date}
-    ${clean}
-    ${skiprows}
-    ${index_type}
-    ${names}
-    ${ofilename}
-    ${xtitle}
-    ${ytitle}
-    ${title}
-    ${figsize}
-    ${legend}
-    ${legend_names}
-    ${subplots}
-    ${sharex}
-    ${sharey}
-    ${colors}
-    ${linestyles}
-    ${markerstyles}
-    ${style}
-    ${xaxis}
-    ${yaxis}
-    ${xlim}
-    ${ylim}
-    secondary_y
-        ${secondary}
-    ${mark_right}
-    ${grid}
-    ${drawstyle}
-    ${por}
-    ${invert_xaxis}
-    ${invert_yaxis}
-    ${round_index}
-    ${source_units}
-    ${target_units}
-    ${plot_styles}
-    ${hlines_y}
-    ${hlines_xmin}
-    ${hlines_xmax}
-    ${hlines_colors}
-    ${hlines_linestyles}
-    ${vlines_x}
-    ${vlines_ymin}
-    ${vlines_ymax}
-    ${vlines_colors}
-    ${vlines_linestyles}
-    """
-    kde_time(
-        input_ts=input_ts,
-        columns=columns,
-        start_date=start_date,
-        end_date=end_date,
-        clean=clean,
-        skiprows=skiprows,
-        index_type=index_type,
-        names=names,
-        ofilename=ofilename,
-        xtitle=xtitle,
-        ytitle=ytitle,
-        title=title,
-        figsize=figsize,
-        legend=legend,
-        legend_names=legend_names,
-        subplots=subplots,
-        sharex=sharex,
-        sharey=sharey,
-        colors=colors,
-        linestyles=linestyles,
-        markerstyles=markerstyles,
-        style=style,
-        xaxis=xaxis,
-        yaxis=yaxis,
-        xlim=xlim,
-        ylim=ylim,
-        secondary_y=secondary_y,
-        mark_right=mark_right,
-        grid=grid,
-        drawstyle=drawstyle,
-        por=por,
-        invert_xaxis=invert_xaxis,
-        invert_yaxis=invert_yaxis,
-        round_index=round_index,
-        source_units=source_units,
-        target_units=target_units,
-        plot_styles=plot_styles,
-        hlines_y=hlines_y,
-        hlines_xmin=hlines_xmin,
-        hlines_xmax=hlines_xmax,
-        hlines_colors=hlines_colors,
-        hlines_linestyles=hlines_linestyles,
-        vlines_x=vlines_x,
-        vlines_ymin=vlines_ymin,
-        vlines_ymax=vlines_ymax,
-        vlines_colors=vlines_colors,
-        vlines_linestyles=vlines_linestyles,
-    )
-
-
 def kde_time(
     input_ts="-",
     columns=None,
@@ -399,6 +237,3 @@ def kde_time(
     if ofilename is not None:
         plt.savefig(ofilename)
     return plt
-
-
-kde_time.__doc__ = kde_time_cli.__doc__
