@@ -1,14 +1,11 @@
 """Collection of functions for the manipulation of time series."""
 
-
 import os
 import warnings
 
-import cltoolbox
 import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
-from cltoolbox.rst_text_formatter import RSTHelpFormatter
 from matplotlib.ticker import FixedLocator
 from toolbox_utils import tsutils
 
@@ -18,154 +15,6 @@ matplotlib.use("Agg")
 warnings.filterwarnings("ignore")
 
 
-@cltoolbox.command("norm_yaxis", formatter_class=RSTHelpFormatter)
-@tsutils.doc(plotutils.ldocstrings)
-def norm_yaxis_cli(
-    input_ts="-",
-    columns=None,
-    start_date=None,
-    end_date=None,
-    clean=False,
-    skiprows=None,
-    index_type="datetime",
-    names=None,
-    ofilename="plot.png",
-    xtitle="",
-    ytitle="",
-    title="",
-    figsize="10,6.0",
-    legend=None,
-    legend_names=None,
-    colors="auto",
-    linestyles="auto",
-    markerstyles=" ",
-    style="auto",
-    xaxis="arithmetic",
-    yaxis="arithmetic",
-    xlim=None,
-    ylim=None,
-    grid=False,
-    drawstyle="default",
-    por=False,
-    invert_xaxis=False,
-    invert_yaxis=False,
-    round_index=None,
-    plotting_position="weibull",
-    prob_plot_sort_values="descending",
-    source_units=None,
-    target_units=None,
-    plot_styles="bright",
-    hlines_y=None,
-    hlines_xmin=None,
-    hlines_xmax=None,
-    hlines_colors=None,
-    hlines_linestyles="-",
-    vlines_x=None,
-    vlines_ymin=None,
-    vlines_ymax=None,
-    vlines_colors=None,
-    vlines_linestyles="-",
-):
-    r"""Normal y-axis.
-
-    "norm_yaxis" will sort, calculate probabilities, and plot data against an
-    y axis normal distribution.
-
-    Parameters
-    ----------
-    ${input_ts}
-    ${columns}
-    ${start_date}
-    ${end_date}
-    ${clean}
-    ${skiprows}
-    ${index_type}
-    ${names}
-    ${ofilename}
-    ${xtitle}
-    ${ytitle}
-    ${title}
-    ${figsize}
-    ${legend}
-    ${legend_names}
-    ${colors}
-    ${linestyles}
-    ${markerstyles}
-    ${style}
-    ${xaxis}
-    ${yaxis}
-    ${xlim}
-    ${ylim}
-    ${grid}
-    ${drawstyle}
-    ${por}
-    ${invert_xaxis}
-    ${invert_yaxis}
-    ${plotting_position}
-    ${prob_plot_sort_values}
-    ${round_index}
-    ${source_units}
-    ${target_units}
-    ${plot_styles}
-    ${hlines_y}
-    ${hlines_xmin}
-    ${hlines_xmax}
-    ${hlines_colors}
-    ${hlines_linestyles}
-    ${vlines_x}
-    ${vlines_ymin}
-    ${vlines_ymax}
-    ${vlines_colors}
-    ${vlines_linestyles}
-    """
-    norm_yaxis(
-        input_ts=input_ts,
-        columns=columns,
-        start_date=start_date,
-        end_date=end_date,
-        clean=clean,
-        skiprows=skiprows,
-        index_type=index_type,
-        names=names,
-        ofilename=ofilename,
-        xtitle=xtitle,
-        ytitle=ytitle,
-        title=title,
-        figsize=figsize,
-        legend=legend,
-        legend_names=legend_names,
-        colors=colors,
-        linestyles=linestyles,
-        markerstyles=markerstyles,
-        style=style,
-        xaxis=xaxis,
-        yaxis=yaxis,
-        xlim=xlim,
-        ylim=ylim,
-        grid=grid,
-        drawstyle=drawstyle,
-        por=por,
-        invert_xaxis=invert_xaxis,
-        invert_yaxis=invert_yaxis,
-        round_index=round_index,
-        plotting_position=plotting_position,
-        prob_plot_sort_values=prob_plot_sort_values,
-        source_units=source_units,
-        target_units=target_units,
-        plot_styles=plot_styles,
-        hlines_y=hlines_y,
-        hlines_xmin=hlines_xmin,
-        hlines_xmax=hlines_xmax,
-        hlines_colors=hlines_colors,
-        hlines_linestyles=hlines_linestyles,
-        vlines_x=vlines_x,
-        vlines_ymin=vlines_ymin,
-        vlines_ymax=vlines_ymax,
-        vlines_colors=vlines_colors,
-        vlines_linestyles=vlines_linestyles,
-    )
-
-
 def norm_yaxis(
     input_ts="-",
     columns=None,
@@ -247,12 +96,10 @@ def norm_yaxis(
         logy = False
         warnings.warn(
             tsutils.error_wrapper(
+                f"""
+                The plot type {plottype} cannot also have the yaxis set to
+                {yaxis}. The {yaxis} setting for yaxis is ignored.
                 """
-The plot type {1} cannot also have the yaxis set to {0}.
-The {0} setting for yaxis is ignored.
-""".format(
-                    yaxis, plottype
-                )
             )
         )
     xlim = plotutils.know_your_limits(xlim, axis=xaxis)
@@ -407,6 +254,3 @@ The {0} setting for yaxis is ignored.
     if ofilename is not None:
         plt.savefig(ofilename)
     return plt
-
-
-norm_yaxis.__doc__ = norm_yaxis_cli.__doc__
