@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import numpy as np
 
 from . import utils
@@ -6,9 +5,9 @@ from . import utils
 
 def centered_rms_dev(predicted, reference):
     """
-    Calculate the centered root-mean-square difference between two variables.
-
-    The latter is calculated using the formula:
+    Calculates the centered root-mean-square (RMS) difference between
+    two variables PREDICTED and REFERENCE (E'). The latter is calculated
+    using the formula:
 
     (E')^2 = sum_(n=1)^N [(p_n - mean(p))(r_n - mean(r))]^2/N
 
@@ -30,7 +29,7 @@ def centered_rms_dev(predicted, reference):
 
     Created on Nov 24, 2016
     """
-    # Check that dimensions of predicted and reference fields match
+
     utils.check_arrays(predicted, reference)
 
     # Calculate means
